pub enum DeviceRegistrationError {
Show 30 variants
AddrsExhausted,
AllocateDeviceAddrs(PciDeviceError),
AllocateIoAddrs(PciDeviceError),
AllocateIoResource(Error),
AllocateIrq,
AllocateIrqResource(VfioError),
AttachDevicePowerDomain(Error),
BrokenPciTopology,
CloneJail(Error),
Cmdline(Error),
ConfigureWindowSize(PciDeviceError),
CreatePipe(Error),
CreateRoot(Error),
CreateSerialDevice(SerialError),
CreateTube(TubeError),
EventClone(Error),
EventCreate(Error),
GenerateAcpi,
IrqsExhausted,
MissingDeviceTreeSymbol,
MissingRequiredSerialDevice(u8),
MmioInsert(BusError),
PciRootAddDevice(PciDeviceError),
ProxyDeviceCreation(ProxyError),
RegisterBattery(BatteryError),
RegisterDevice(SendError<PciRootCommand>),
RegisterDeviceCapabilities(PciDeviceError),
RegisterIoevent(Error),
RegisterIrqfd(Error),
SetupVfioPlatformIrq(Error),
}Expand description
Errors for device manager.
Variants
AddrsExhausted
No more MMIO space available.
AllocateDeviceAddrs(PciDeviceError)
Could not allocate device address space for the device.
AllocateIoAddrs(PciDeviceError)
Could not allocate IO space for the device.
AllocateIoResource(Error)
Could not allocate MMIO or IO resource for the device.
AllocateIrq
Could not allocate an IRQ number.
AllocateIrqResource(VfioError)
Could not allocate IRQ resource for the device.
AttachDevicePowerDomain(Error)
BrokenPciTopology
Broken pci topology
CloneJail(Error)
Unable to clone a jail for the device.
Cmdline(Error)
Appending to kernel command line failed.
ConfigureWindowSize(PciDeviceError)
Configure window size failed.
CreatePipe(Error)
CreateRoot(Error)
CreateSerialDevice(SerialError)
CreateTube(TubeError)
EventClone(Error)
Could not clone an event.
EventCreate(Error)
Could not create an event.
GenerateAcpi
Failed to generate ACPI content.
IrqsExhausted
No more IRQs are available.
MissingDeviceTreeSymbol
VFIO device is missing a DT symbol.
MissingRequiredSerialDevice(u8)
Missing a required serial device.
MmioInsert(BusError)
Could not add a device to the mmio bus.
PciRootAddDevice(PciDeviceError)
Failed to insert device into PCI root.
ProxyDeviceCreation(ProxyError)
Failed to initialize proxy device for jailed device.
RegisterBattery(BatteryError)
Failed to register battery device.
RegisterDevice(SendError<PciRootCommand>)
Could not register PCI device to pci root bus
RegisterDeviceCapabilities(PciDeviceError)
Could not register PCI device capabilities.
RegisterIoevent(Error)
Failed to register ioevent with VM.
RegisterIrqfd(Error)
Failed to register irq event with VM.
SetupVfioPlatformIrq(Error)
Could not setup VFIO platform IRQ for the device.