pub enum VcpuAffinity {
Global(CpuSet),
PerVcpu(BTreeMap<usize, CpuSet>),
}Expand description
Mapping of guest VCPU threads to host CPU cores.
Variants
Global(CpuSet)
All VCPU threads will be pinned to the same set of host CPU cores.
PerVcpu(BTreeMap<usize, CpuSet>)
Each VCPU may be pinned to a set of host CPU cores. The map key is a guest VCPU index, and the corresponding value is the set of host CPU indices that the VCPU thread will be allowed to run on. If a VCPU index is not present in the map, its affinity will not be set.